aboutsummaryrefslogtreecommitdiff
path: root/plugins-scripts/check_ifoperstatus.pl
diff options
context:
space:
mode:
Diffstat (limited to 'plugins-scripts/check_ifoperstatus.pl')
-rwxr-xr-xplugins-scripts/check_ifoperstatus.pl10
1 files changed, 5 insertions, 5 deletions
diff --git a/plugins-scripts/check_ifoperstatus.pl b/plugins-scripts/check_ifoperstatus.pl
index 588993be..abcec68f 100755
--- a/plugins-scripts/check_ifoperstatus.pl
+++ b/plugins-scripts/check_ifoperstatus.pl
@@ -1,9 +1,9 @@
#!/usr/local/bin/perl -w
#
-# check_ifoperstatus.pl - nagios plugin
+# check_ifoperstatus.pl - monitoring plugin
#
# Copyright (C) 2000 Christoph Kron,
-# Modified 5/2002 to conform to updated Nagios Plugin Guidelines
+# Modified 5/2002 to conform to updated Monitoring Plugins Guidelines
# Added support for named interfaces per Valdimir Ivaschenko (S. Ghosh)
# Added SNMPv3 support (10/2003)
#
@@ -22,7 +22,7 @@
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#
-# Report bugs to: nagiosplug-help@lists.sourceforge.net
+# Report bugs to: help@monitoring-plugins.org
#
# 11.01.2000 Version 1.0
#
@@ -97,7 +97,7 @@ my %session_opts;
$status = process_arguments();
# Just in case of problems, let's not hang Nagios
$SIG{'ALRM'} = sub {
print ("ERROR: No snmp response from $hostname (alarm)\n");
exit $ERRORS{"UNKNOWN"};
@@ -288,7 +288,7 @@ sub print_usage() {
sub print_help() {
print_revision($PROGNAME, '@NP_VERSION@');
print_usage();
- printf "check_ifoperstatus plugin for Nagios monitors operational \n";
+ printf "check_ifoperstatus plugin for monitoring operational \n";
printf "status of a particular network interface on the target host\n";
printf "\nUsage:\n";
printf " -H (--hostname) Hostname to query - (required)\n";
@@ -97,7 +97,7 @@ my %session_opts;
$status = process_arguments();
-# Just in case of problems, let's not hang Nagios
+# Just in case of problems, let's not hang the monitoring system
$SIG{'ALRM'} = sub {
print ("ERROR: No snmp response from $hostname (alarm)\n");